@@ -26,7 +26,7 @@ class LegendWidget : public QWidget
 public:
     explicit LegendWidget(QWidget *parent);
 
-    ~LegendWidget();
+    ~LegendWidget() override;
 
     void LockWidget();
     void UnLockWidget();
@@ -50,11 +50,11 @@ private:
 
     QPixmap m_pixmap;
 
-    QList<LegendItem*> m_legendItemList;
+    QList<LegendItem *> m_legendItemList;
 
     Qt::DockWidgetArea m_dockArea;
 
-    void updateLegendItemLayout(const QList<legendPair>& list);
+    void updateLegendItemLayout(const QList<legendPair> &list);
 };
 
 /**
@@ -68,8 +68,8 @@ class LegendItem : public QLabel
     Q_OBJECT
 
 public:
-    LegendItem(const QPair<QString, QColor>& pair, LegendWidget * parent = nullptr);
-    ~LegendItem() {}
+    LegendItem(const QPair<QString, QColor> &pair, LegendWidget *parent = nullptr);
+    ~LegendItem() override = default;
 
 Q_SIGNALS:
     void legenItemHoovered(QColor color);
@@ -78,9 +78,12 @@ private:
     QColor legendItemColor;
 
 protected:
-    void enterEvent(QEvent * event) override;
-    void leaveEvent(QEvent * event) override;
-
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void enterEvent(QEnterEvent *event) override;
+#else
+    void enterEvent(QEvent *event) override;
+#endif
+    void leaveEvent(QEvent *event) override;
 };
 
 #endif // LEGENDWIDGET_H
