@@ -11,6 +11,7 @@
 #include <QCommandLineParser>
 
 #include <KAboutData>
+#include <KCrash>
 #include <KLocalizedString>
 
 #include "kalzium.h"
@@ -93,6 +94,8 @@ int main(int argc, char **argv)
 
     KAboutData::setApplicationData(about);
 
+    KCrash::initialize();
+
     QCommandLineParser parser;
 
 #if defined(HAVE_OPENBABEL) && defined(HAVE_EIGEN) && defined(HAVE_AVOGADRO)
