@@ -9,8 +9,8 @@
 
 #include <QWidget>
 
-#include "spectrum.h"
 #include "prefs.h"
+#include "spectrum.h"
 
 /**
  * @author Carsten Niehaus
@@ -22,11 +22,11 @@ class SpectrumWidget : public QWidget
 public:
     explicit SpectrumWidget(QWidget *parent);
 
-    ~SpectrumWidget() override {}
+    ~SpectrumWidget() override = default;
 
-    void setSpectrum(Spectrum* spec);
+    void setSpectrum(Spectrum *spec);
 
-    Spectrum* spectrum()const
+    Spectrum *spectrum() const
     {
         return m_spectrum;
     }
@@ -44,10 +44,7 @@ public:
     /**
      * there are several possible types.
      */
-    enum SpectrumType {
-        EmissionSpectrum = 0,
-        AbsorptionSpectrum
-    };
+    enum SpectrumType { EmissionSpectrum = 0, AbsorptionSpectrum };
 
     /**
      * sets the type of the spectrum to @p t
@@ -100,7 +97,7 @@ public:
      */
     inline double Wavelength(double xpos)
     {
-        return m_startValue + ((m_endValue - m_startValue) *  xpos);
+        return m_startValue + ((m_endValue - m_startValue) * xpos);
     }
 
     /**
@@ -148,8 +145,8 @@ private:
 
     QPixmap m_pixmap;
 
-    void paintBands(QPainter* p);
-    void drawZoomLine(QPainter* p);
+    void paintBands(QPainter *p);
+    void drawZoomLine(QPainter *p);
 
     /**
      * Draw the scale
@@ -188,7 +185,7 @@ public Q_SLOTS:
         update();
     }
 
-signals:
+Q_SIGNALS:
     /**
      * the minimum and maximum displayed wavelength have
      * changed so emit the new minimum and maximum
@@ -198,7 +195,7 @@ signals:
     /**
      * the user selected a peak
      */
-    void peakSelected(Spectrum::peak * peak);
+    void peakSelected(Spectrum::peak *peak);
 
 private Q_SLOTS:
     void slotZoomIn();
